# pdok-service-md-extractor

Converts (geo) service metadata documents (ISO 19119) to JSON. For now specifically targets "Nederlands metadata profiel op ISO 19119 voor services 1.2" metadata documents. 

## Dependencies

See `requirements.txt`. 

## Usage

```
convert-metadata example/19119_1.2_atom.xml
```